/// <reference types="node" />
import { bigInt } from 'snarkjs';
import { Groth16 } from 'websnark/src/groth16';
import { MerkleTree, Element, HashFunction } from 'fixed-merkle-tree';
export type bigInt = typeof bigInt;
/**
 * These are types which define and scope (!) the outputs of the cryptograhic
 * functions. They have been scoped such that there isn't much naming confusion
 * between what a function takes and not. Common aliases are used there where deemed
 * appropriate.
 */
export declare namespace OutputOf {
    type PedersenHash = bigInt;
    interface CreateDeposit {
        nullifier: bigInt;
        secret: bigInt;
        preimage: Buffer;
        commitment: PedersenHash;
        hexCommitment: string;
        nullifierHash: PedersenHash;
        hexNullifierHash: string;
    }
    interface MerkleProof {
        root: any;
        path: {
            indices: any;
            elements: any[];
        };
    }
    interface Groth16Proof {
        pi_a: string;
        pi_b: string;
        pi_c: string;
    }
}
export type MerkleProof = OutputOf.MerkleProof;
export type DepositProof = OutputOf.Groth16Proof;
/**
 * These are types which define and scope (!) the inputs of the cryptograhic
 * functions. The same as above applies, but note that some outputs are inputs
 * for other functions. For example, MerkleTree is an output of the function
 * which builds the Tornado Cash merkle tree, and this is passed as input,
 * to the merkle proof builder.
 */
export declare namespace InputFor {
    export interface PedersenHash {
        msg: Buffer;
    }
    export interface CreateDeposit {
        nullifier?: bigInt;
        secret?: bigInt;
    }
    export interface BuildMerkleTree {
        height: number;
        leaves: Array<Element>;
    }
    export interface DepositProof {
        public: {
            root: Element;
            tree: MerkleTree;
            leafIndex: number;
            hexNullifierHash: string;
            recipientAddress: string;
            relayerAddress: string;
            fee: bigInt;
            refund: bigInt;
        };
        private: {
            nullifier: bigInt;
            secret: bigInt;
        };
    }
    interface PublicGroth16 {
        root: any;
        nullifierHash: PedersenHash;
        recipient: bigInt;
        relayer: bigInt;
        refund: bigInt;
        fee: bigInt;
    }
    interface PrivateGroth16 {
        nullifier: bigInt;
        secret: bigInt;
        pathIndices: number[];
        pathElements: string[];
    }
    export type Groth16 = PublicGroth16 & PrivateGroth16;
    export {};
}
export type DepositInfo = OutputOf.CreateDeposit;
/**
 * Several objects have to be set up, like the groth16 prover. All related types are
 * (will be) contained within this namespace.
 */
export declare namespace Setup {
    function getZeroElement(): string;
    function getDefaultHash(): HashFunction<Element>;
    function getProvingKey(): ArrayBufferLike;
    function getTornadoCircuit(): any;
    function getGroth16(): Promise<Groth16>;
    function terminateGroth16(): void;
}
/**
 * These are the important cryptographic primitives Tornado Cash uses.
 */
export declare namespace Primitives {
    function calcPedersenHash(pedersenHashData: InputFor.PedersenHash): OutputOf.PedersenHash;
    function createNote(msg: Buffer): string;
    function parseNote(hexNote: string): DepositInfo;
    function createDeposit(input?: InputFor.CreateDeposit): DepositInfo;
    function buildMerkleTree(inputs: InputFor.BuildMerkleTree): MerkleTree;
    function calcDepositProofs(inputs: Array<InputFor.DepositProof>): Promise<Array<Array<string>>>;
}
//# sourceMappingURL=index.d.ts.map